package main

import (
	"flag"
	"fmt"
	"os"

	//packrd "git.paulbsd.com/paulbsd/dip/packrd"
	"git.paulbsd.com/paulbsd/dip/src/ip"
	"git.paulbsd.com/paulbsd/dip/src/static"
	"git.paulbsd.com/paulbsd/dip/src/templates"
	"github.com/gobuffalo/packr/v2"
	"github.com/labstack/echo/v4"
)

func main() {
	e := echo.New()
	e.HideBanner = true

	var host, port string

	flag.Usage = Usage
	flag.StringVar(&host, "host", "[::]", "Listen host")
	flag.StringVar(&port, "port", "8080", "Listen port")
	flag.Parse()

	templatesbox := packr.New("templates", "./templates")
	staticbox := packr.New("static", "./static")

	builtTemplates, _ := templates.BuildTemplates(templatesbox)
	e.Renderer = builtTemplates

	e.GET("/", ip.Dip)
	e.GET("/static/*", func(c echo.Context) error {
		return static.Static(staticbox, c)
	})

	e.Logger.Fatal(e.Start(fmt.Sprintf("%s:%s", host, port)))
}

// Usage displays possible arguments
func Usage() {
	flag.PrintDefaults()
	os.Exit(1)
}
